function grim_ballonseesaw(in)

Xcmd     = in(1);       % ball position command
X        = in(2);       % ball position
theta    = in(3);       % seesaw angle
t        = in(4);       % time

l = 0.15;               % 1/2 seesaw length
r = 0.012;              % ball radius
h0 = 0.03;              % support height

FS=12;
if abs(t)<0.001
    figure(10)
    axis equal;
    axis([-0.2 0.2 -0.1 0.2]);
    h=xlabel('X [m]'); set(h,'FontSize',FS);
    h=gca; set(h,'FontSize',FS);
    hold on;
end
cla;

% ---------------------
% drawings
% --------------------

% floor line
plot([-1.5 1.5],[0 0],':');

% triangle support
h=plot([0 -0.02 0.02 0],[0.029 0 0 0.029],'k'); set(h,'LineWidth',2);

% seesaw
X1 = l*cos(theta);
X2 = -X1;
Y1 = h0-l*sin(theta);
Y2 = h0+l*sin(theta);
h=plot([X1 X2],[Y1 Y2],'b'); set(h,'LineWidth',2);

% ball
Xc = X*cos(theta)+r*sin(theta);         % ball center
Yc = h0-X*sin(theta)+r*cos(theta);      % ball center
zeta = linspace(0,2*pi,100);
X_array = Xc+r*cos(zeta);
Y_array = Yc+r*sin(zeta);
h=plot(X_array,Y_array,'r'); set(h,'LineWidth',2);

% a small dot on the ball
phi = X/r+theta;            % ball rotation angle
X1 = Xc+0.7*r*sin(phi);
Y1 = Yc+0.7*r*cos(phi);
h=plot(X1,Y1,'r.'); set(h,'LineWidth',2);

% some texts: Xcmd & time
h=text(-0.15, 0.15,'Xcmd = '); set(h,'FontSize',FS);
h=text(-0.09, 0.15, num2str(Xcmd)); set(h,'FontSize',FS+2); set(h,'Color','r');
h=text( 0.12, 0.15, num2str(round(t))); set(h,'FontSize',FS);
h=text( 0.15, 0.15,'[sec]'); set(h,'FontSize',FS);

CHOICE_MOVIE=0;
if CHOICE_MOVIE==1
    no=num2str(round(t*20));
    str=['Movie\movie', no];
    saveas(gcf,str,'m');
end

drawnow